@@ -31,7 +31,8 @@ def mapper(
         @data (GeoDataFrame): base entera con los datos a graficar
         @variable (str): nombre de la variable que se quiere graficar
         @path_maps (str): Ruta de la carpeta en la que se exporta. Si se corrio la plantilla, debería llamarse path_maps
-        @aglo (str, optional): Aglomerado en el que enfocar. Defaults to 'amba'.
+        @aglo (str, optional): Aglomerado en el que enfocar. Defaults to 'amba'. 
+            Se pueden usar all_aglos() o all_aglos_arg() (si se necesita Argentina) para que devuelva la lista y usarla en el loop ( for aglo in all_aglos(): mapper(gdf, aglo=aglo) )  
         @remove_zeros (bool, optional): Remueve las filas con 0 (o '.') en la variable a graficar
             Si no se remueven los ceros, tarda mucho en graficar los poligonos. 
         @label (str, optional): Etiqueta que se muestra al pasar el mouse por el área pintada (solo en HTML). Defaults to None.
@@ -63,20 +64,22 @@ def mapper(
     import pandas as pd
     import numpy as np
     import plotly.express as px
+    import os
+    
 
     
     #ZOOMS
-    zoom_center =  {'argentina': (3.18,-39.249,-61.960),
-                    'amba':      (9.34,-34.637,-58.434),
-                    'cordoba':   (10.46,-31.406,-64.194),
-                    'rosario':   (10.44,-32.955,-60.678),
-                    'mendoza':   (11.36,-32.900,-68.829),
-                    'tucuman':   (10.89,-26.819,-65.197),
-                    'la_plata':  (10.49,-34.924,-57.941),
+    zoom_center =  {'argentina'    : (3.18,-39.249,-61.960),
+                    'amba'         : (9.34,-34.637,-58.434),
+                    'cordoba'      : (10.46,-31.406,-64.194),
+                    'rosario'      : (10.44,-32.955,-60.678),
+                    'mendoza'      : (11.36,-32.900,-68.829),
+                    'tucuman'      : (10.89,-26.819,-65.197),
+                    'la_plata'     : (10.49,-34.924,-57.941),
                     'mar_del_plata': (10.53,-38.006,-57.523),
-                    'salta':     (12.58,-24.794,-65.403),
-                    'san_juan':  (10.74,-31.548,-68.491),
-                    'santa_fe':  (11.72,-31.625,-60.699)
+                    'salta'        : (12.58,-24.794,-65.403),
+                    'san_juan'     : (10.74,-31.548,-68.491),
+                    'santa_fe'     : (11.72,-31.625,-60.699)
                    }
     
     pd.options.mode.chained_assignment = None  # default='warn'
@@ -110,13 +113,14 @@ def mapper(
 
     if not colorscale:
         if colorscale_type == 'discrete':
-            colorscale = ['#edbe2e', '#da6b1f']
+            # colorscale = ['#edbe2e', '#da6b1f']
             #Escala colores ministerio:
-            # colorscale=["#ffffff", "#00b0f0"]     
+            colorscale=["#00b0f0","#ffffff"]     
         elif colorscale_type == 'continuous':
             colorscale = [(0, '#5A53A4'),(0.22, '#64C0A6'),(0.44, '#E7F599'),(0.7, '#FEDE89'),(0.93, '#FB9E5A'),(1, '#A70B44')]
         elif colorscale_type == 'map':
-            colorscale = {"1": "#da6b1f", "2": "#edbe2e"}
+            # colorscale = {"1": "#da6b1f", "2": "#edbe2e"}
+            colorscale={'1':"#00b0f0", '2':"#ffffff"}
         else:
             raise ValueError('El tipo de escala de colores tiene que ser "discrete", "map" o "continuous')
 
@@ -244,6 +248,8 @@ def mapper(
 
     if subfolder:
         path_maps += f'\\{subfolder}'
+    if not os.path.exists(path_maps):
+        os.makedirs(path_maps, exist_ok=True)
     
     #NAME
     if nombre:
@@ -265,4 +271,31 @@ def mapper(
     pd.options.mode.chained_assignment = 'warn'  # default='warn'
 
     print(f'Mapa creado en {out_name}')
-    # return fig
\ No newline at end of file
+    # return fig
+    
+    
+def all_aglos_arg():
+    return ['argentina', 
+            'amba',
+            'cordoba',
+            'rosario',
+            'mendoza',
+            'tucuman',
+            'la_plata',
+            'mar_del_plata',
+            'salta',
+            'san_juan',     
+            'santa_fe']
+    
+    
+def all_aglos():
+    return ['amba',
+            'cordoba',
+            'rosario',
+            'mendoza',
+            'tucuman',
+            'la_plata',
+            'mar_del_plata',
+            'salta',
+            'san_juan',
+            'santa_fe']
\ No newline at end of file
